module Pages exposing (init)

{-| This module is the entrypoint to the infrastructure for pages. Specific kinds of pages
and implementations of page fragments should all be submodules of this module.
-}

import Common exposing (..)
import Pages.Common exposing (..)
import Routes.Common exposing (..)
import Html exposing (Html)
import Html.Events as Evt
import Html.Attributes as Attr


init : GlobalModel -> ( Page, Session )
init global =
    let
        session =
            ()

        page =
            simplePage <| const2 <| initialContent1 global
    in
        ( page, session )


initialContent1 : GlobalModel -> Html Msg
initialContent1 global =
    let
        nextPage =
            simplePage <| const2 initialContent2
    in
        Html.div []
            [ Html.img [ assetSrc global "example.png" ] []
            , Html.div [] [ Html.text "I am Jack's initial page." ]
            , Html.div [] [ Html.text "I am another line on Jack's initial page." ]
            , Html.button
                [ Attr.type_ "button"
                , Attr.class "mdc-button mdc-button--raised mdc-button--primary mdc-ripple-surface"
                , mdcAutoInit "Ripple"
                , Evt.onClick <| NavTo <| UpdatePage nextPage
                ]
                [ Html.text "Wanna hear a joke? Swipe right." ]
            ]


initialContent2 : Html Msg
initialContent2 =
    Html.div []
        [ Html.div [] [ faList [ "circle-o-notch", "spin", "5x", "fw" ] ]
        , Html.div [] [ Html.text "I am the next page." ]
        , Html.button
            [ Attr.type_ "button"
            , Attr.class "mdc-button mdc-button--raised mdc-button--primary mdc-ripple-surface"
            , mdcAutoInit "Ripple"
            , Evt.onClick <| NavTo <| GoToRoute InitialRoute
            ]
            [ Html.text "Load initial route." ]
        ]
